@@ -1,6 +1,6 @@
 package App::Deps::Verify;
-$App::Deps::Verify::VERSION = '0.10.0';
-# ABSTRACT: An app and API to verify the presence of dependencies (Perl 5 modules, python3 modules, executables, etc.
+$App::Deps::Verify::VERSION = '0.10.1';
+# ABSTRACT: An app and API to verify the presence of dependencies (Perl 5 modules, python3 modules, executables, etc.)
 
 use strict;
 use warnings;
@@ -351,9 +351,13 @@ __END__
 
 =encoding UTF-8
 
+=head1 NAME
+
+App::Deps::Verify - app and API to verify the presence of dependencies (Perl 5 modules, python3 modules, executables, etc.)
+
 =head1 VERSION
 
-version 0.10.0
+version 0.10.1
 
 =head1 SYNOPSIS
 
@@ -429,14 +433,6 @@ L<https://metacpan.org/release/App-Deps-Verify>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/App-Deps-Verify>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -445,14 +441,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-Deps-Verify>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/App-Deps-Verify>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
